==> update-manager_0.150.3.tar.gz: update-manager-0.150.3/tests/test_xorg_fix_intrepid.py <==
#!/usr/bin/python

import os
import sys
sys.path.insert(0,"../")

import apt
import unittest
import shutil
import subprocess
import re

from DistUpgrade.xorg_fix_proprietary import comment_out_driver_from_xorg, replace_driver_from_xorg, is_multiseat

class testOriginMatcher(unittest.TestCase):
    ORIG="test-data/xorg.conf.orig"
    FGLRX="test-data/xorg.conf.fglrx"
    MULTISEAT="test-data/xorg.conf.multiseat"
    NEW="test-data/xorg.conf"


    def testSimple(self):
        shutil.copy(self.ORIG, self.NEW)
        replace_driver_from_xorg("fglrx", "ati", self.NEW)
        self.assert_(open(self.ORIG).read() == open(self.NEW).read())
    def testRemove(self):
        shutil.copy(self.FGLRX, self.NEW)
        self.assert_("fglrx" in open(self.NEW).read())
        replace_driver_from_xorg("fglrx", "ati", self.NEW)
        self.assert_(not "fglrx" in open(self.NEW).read())
    def testMultiseat(self):
        self.assert_(is_multiseat(self.ORIG) == False)
        self.assert_(is_multiseat(self.FGLRX) == False)
        self.assert_(is_multiseat(self.MULTISEAT) == True)
    def testComment(self):
        shutil.copy(self.FGLRX, self.NEW)
        comment_out_driver_from_xorg("fglrx",self.NEW)
        for line in open(self.NEW):
            if re.match('^#.*Driver.*fglrx',line):
                logging.info("commented out line found")
                break
        else:
            raise Exception("commenting the line did *not* work")
        

if __name__ == "__main__":
    import logging
    logging.basicConfig(level=logging.DEBUG)
    unittest.main()

==> update-manager_0.164.tar.gz: update-manager-0.164/tests/test_xorg_fix_intrepid.py <==
#!/usr/bin/python

import sys
sys.path.insert(0,"../")

import unittest
import shutil
import re

from DistUpgrade.xorg_fix_proprietary import comment_out_driver_from_xorg, replace_driver_from_xorg, is_multiseat

class testOriginMatcher(unittest.TestCase):
    ORIG="test-data/xorg.conf.orig"
    FGLRX="test-data/xorg.conf.fglrx"
    MULTISEAT="test-data/xorg.conf.multiseat"
    NEW="test-data/xorg.conf"


    def testSimple(self):
        shutil.copy(self.ORIG, self.NEW)
        replace_driver_from_xorg("fglrx", "ati", self.NEW)
        self.assertEqual(open(self.NEW).read(), open(self.ORIG).read())
    def testRemove(self):
        shutil.copy(self.FGLRX, self.NEW)
        self.assertTrue("fglrx" in open(self.NEW).read())
        replace_driver_from_xorg("fglrx", "ati", self.NEW)
        self.assertFalse("fglrx" in open(self.NEW).read())
    def testMultiseat(self):
        self.assertFalse(is_multiseat(self.ORIG))
        self.assertFalse(is_multiseat(self.FGLRX))
        self.assertTrue(is_multiseat(self.MULTISEAT))
    def testComment(self):
        shutil.copy(self.FGLRX, self.NEW)
        comment_out_driver_from_xorg("fglrx",self.NEW)
        for line in open(self.NEW):
            if re.match('^#.*Driver.*fglrx',line):
                logging.info("commented out line found")
                break
        else:
            raise Exception("commenting the line did *not* work")
        

if __name__ == "__main__":
    import logging
    logging.basicConfig(level=logging.DEBUG)
    unittest.main()
